@@ -138,6 +138,11 @@ typedef struct{
 	gboolean view_priv_items;
 }EwsDelegateInfo;
 
+typedef enum {
+	NORMAL_FIELD_URI,
+	INDEXED_FIELD_URI,
+	EXTENDED_FIELD_URI
+} EwsFieldURIType;
 
 typedef struct {
 	gchar *distinguished_prop_set_id;
@@ -159,6 +164,21 @@ typedef struct {
 	GSList *indexed_furis;
 } EwsAdditionalProps;
 
+typedef struct {
+	gchar *order;
+	gint uri_type;
+	gpointer field_uri;
+} EwsSortOrder;
+
+typedef struct {
+	gchar *state;		/*Out of office state*/
+	gchar *ext_aud;		/*external audience*/
+	time_t start_tm;	/*Start time*/
+	time_t end_tm;		/*End time*/
+	gchar *int_reply;	/*Internal Reply*/
+	gchar *ext_reply;	/*External Reply*/
+} OOFSettings;
+
 GType		e_ews_connection_get_type	(void);
 EEwsConnection *e_ews_connection_new		(const gchar *uri,
 						 const gchar *username,
@@ -223,6 +243,47 @@ gboolean	e_ews_connection_sync_folder_items
 						 GCancellable *cancellable,
 						 GError **error);
 
+typedef void	(*EwsConvertQueryCallback) (ESoapMessage *msg,
+						 const gchar *query,
+						 EwsFolderType type);
+
+void		e_ews_connection_find_folder_items_start
+						(EEwsConnection *cnc,
+						 gint pri,
+						 EwsFolderId *fid,
+						 const gchar *props,
+						 EwsAdditionalProps *add_props,
+						 EwsSortOrder *sort_order,
+						 const gchar *query,
+						 EwsFolderType type,
+						 EwsConvertQueryCallback convert_query_cb,
+						 GAsyncReadyCallback cb,
+						 GCancellable *cancellable,
+						 gpointer user_data);
+
+gboolean	e_ews_connection_find_folder_items_finish
+						(EEwsConnection *cnc,
+						 GAsyncResult *result,
+						 gboolean *includes_last_item,
+						 GSList **items,
+						 GError **error);
+
+gboolean	e_ews_connection_find_folder_items
+						(EEwsConnection *cnc,
+						 gint pri,
+						 EwsFolderId *fid,
+						 const gchar *default_props,
+						 EwsAdditionalProps *add_props,
+						 EwsSortOrder *sort_order,
+						 const gchar *query,
+						 EwsFolderType type,
+						 gboolean *includes_last_item,
+						 GSList **items,
+						 EwsConvertQueryCallback convert_query_cb,
+						 GCancellable *cancellable,
+						 GError **error);
+
+
 /* Get folder items */
 void		e_ews_connection_get_items_start
 						(EEwsConnection *cnc,
@@ -759,8 +820,41 @@ gboolean e_ews_connection_get_delegate
 						 GCancellable *cancellable,
 						 GError **error);
 
+void		e_ews_connection_get_oof_settings_start	(EEwsConnection *cnc,
+							 gint pri,
+							 GAsyncReadyCallback cb,
+							 GCancellable *cancellable,
+							 gpointer user_data);
 
+gboolean	e_ews_connection_get_oof_settings_finish (EEwsConnection *cnc,
+							  GAsyncResult *result,
+							  OOFSettings **oof_settings,
+							  GError **error);
 
+gboolean	e_ews_connection_get_oof_settings (EEwsConnection *cnc,
+						   gint pri,
+						   OOFSettings **oof_settings,
+						   GCancellable *cancellable,
+						   GError **error);
+
+void		e_ews_connection_set_oof_settings_start	(EEwsConnection *cnc,
+							 gint pri,
+							 OOFSettings *oof_settings,
+							 GAsyncReadyCallback cb,
+							 GCancellable *cancellable,
+							 gpointer user_data);
+
+gboolean	e_ews_connection_set_oof_settings_finish (EEwsConnection *cnc,
+							  GAsyncResult *result,
+						 	  GError **error);
+
+gboolean	e_ews_connection_set_oof_settings (EEwsConnection *cnc,
+					 	   gint pri,
+					 	   OOFSettings *oof_settings,
+					 	   GCancellable *cancellable,
+					 	   GError **error);
+
+void		e_ews_connection_free_oof_settings (OOFSettings *oof_settings);
 
 G_END_DECLS
 
